@@ -12,7 +12,7 @@ urlpatterns = [
 
     path('', views.get_products, name='list'),
 
-    path('add-product/', views.add_product, name='add'),
+    path('add-product/', views.AddProductView.as_view(), name='add'),
 
     path('bar-code-to-id/', views.get_id_from_bar_code,
          name='bar-code-to-id'),
