@@ -1,16 +1,18 @@
 
 from django.contrib.admin.views.decorators import staff_member_required
 from django.http.response import (
-    HttpResponseForbidden, HttpResponseBadRequest, JsonResponse)
+    HttpResponseForbidden,
+    HttpResponseBadRequest,
+    JsonResponse)
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.http import require_GET, require_POST
+from django.views import View
+from django.utils.decorators import method_decorator
 
 from cap.decorators import admin_render_view
 from cap.views import render
 
-from rest_framework.decorators import api_view, APIView
-from rest_framework.response import Response
-
 from pagination import paginate
 from djforms import get_clean_data
 from invoices.models import Sale
@@ -92,7 +94,7 @@ def add_service_item(request):
         status=status_code)
 
 
-@api_view(['GET'])
+@require_GET
 @staff_member_required
 def get_service_items(request):
 
@@ -103,7 +105,7 @@ def get_service_items(request):
         ServiceItem.objects.search(**get_clean_data(form)),
         per_page=30)
 
-    return Response({
+    return JsonResponse({
         'items': render_to_string('services/service-items.html', {
             'request': request,
             'page_obj': page
@@ -112,16 +114,16 @@ def get_service_items(request):
     })
 
 
-@api_view(['POST'])
+@require_POST
 def add_service(request, sale_id):
 
     sale = request.invoices.get_sale(sale_id)
 
-    service_item = ServiceItem.objects.get(pk=request.data['service_item'])
+    service_item = ServiceItem.objects.get(pk=request.POST['service_item'])
 
     service = request.services.add_service(sale, service_item)
 
-    return Response({
+    return JsonResponse({
         'message': _('Service added'),
         'status': 'OK',
         'html': service.render(),
@@ -130,18 +132,19 @@ def add_service(request, sale_id):
     })
 
 
-class ServiceAPI(APIView):
+@method_decorator(staff_member_required, 'dispatch')
+class ServiceAPI(View):
 
     def post(self, request, service_id):
 
         service = request.services.get_service(service_id)
 
         try:
-            service.update(request.data)
+            service.update(request.POST)
         except ValueError as e:
             return HttpResponseBadRequest(str(e))
 
-        return Response({
+        return JsonResponse({
             'message': _('Service updated'),
             'total': service.sale.serialize_totals()
         })
@@ -157,7 +160,7 @@ class ServiceAPI(APIView):
 
         service.delete()
 
-        return Response({
+        return JsonResponse({
             'message': _('Service removed'),
             'total': sale.serialize_totals()
         })
